@@ -41,7 +41,7 @@ def execute_request(
     if response.status_code == 500:
       raise ValueError("Internal error. Please contact support.")
 
-    raise ValueError(json.loads(response.text)["description"])
+    raise ValueError(json.loads(response.text)["message"])
 
   if response.headers.get('content-type') == 'application/json':
     return response.json()
