@@ -2,9 +2,9 @@ from io import StringIO
 import pandas as pd
 from typing import List, Union
 from time import sleep
-from tim.types import Logs, Status, StatusResponse
+from tim.types import ExecuteResponse, Logs, Status, StatusResponse
 from tim.core.api import execute_request
-from tim.data_sources.anomaly_detection.types import AnomalyDetectionJobModelResult, AnomalyDetection, BuildModelResponse, AnomalyDetectionJobConfiguration, ExecuteResponse, AnomalyDetectionListPayload
+from tim.data_sources.anomaly_detection.types import AnomalyDetectionJobModelResult, AnomalyDetection, BuildModelResponse, AnomalyDetectionJobConfiguration, AnomalyDetectionDetectConfiguration, AnomalyDetectionListPayload
 from tim.core.credentials import Credentials
 
 
@@ -12,7 +12,19 @@ def build_model(
     credentials: Credentials, job_configuration: AnomalyDetectionJobConfiguration
 ) -> BuildModelResponse:
   return execute_request(
-      credentials, method='post', path='/detection-jobs/build-model', body=job_configuration
+      credentials=credentials, method='post', path='/detection-jobs/build-model', body=job_configuration
+  )
+
+
+def detect(
+    credentials: Credentials, parent_job_id: str,
+    job_configuration: Union[AnomalyDetectionDetectConfiguration, None]
+) -> BuildModelResponse:
+  return execute_request(
+      credentials=credentials,
+      method='post',
+      path=f'/detection-jobs/{parent_job_id}/detect',
+      body=job_configuration
   )
 
 
@@ -38,11 +50,11 @@ def get_anomaly_detection_jobs(
     limit: int,
     sort: str,
     experiment_id: Union[str, None] = None,
-    useCase_id: Union[str, None] = None,
+    use_case_id: Union[str, None] = None,
     type: Union[str, None] = None,
 ) -> List[AnomalyDetection]:
   payload = AnomalyDetectionListPayload(
-      experimentId=experiment_id, useCaseId=useCase_id, sort=sort, type=type, limit=limit, offset=offset
+      experimentId=experiment_id, useCaseId=use_case_id, sort=sort, type=type, limit=limit, offset=offset
   )
 
   return execute_request(credentials=credentials, method='get', path=f'/detection-jobs', params=payload)
