@@ -1,12 +1,27 @@
 from enum import Enum
-from tim.types import Logs
-from typing import List, NamedTuple, Optional
+from tim.types import Logs, Status, Id, Version
+from typing import List, Union, NamedTuple, Optional
 from typing_extensions import TypedDict
 from pandas.core.frame import DataFrame
 
+
+class BaseUnit(Enum):
+  DAY = 'Day'
+  HOUR = 'Hour'
+  MINUTE = 'Minute'
+  SECOND = 'Second'
+  MONTH = 'Month'
+  SAMPLE = 'Sample'
+
+
 Range = TypedDict('Range', {'from': str, 'to': str})
 
 
+class RelativeRange(TypedDict):
+  baseUnit: BaseUnit
+  value: int
+
+
 class ImputationTypeEnum(Enum):
   LINEAR = 'Linear'
   LOCF = 'LOCF'
@@ -20,6 +35,12 @@ class BasicBaseUnitEnum(Enum):
   SECOND = 'Second'
 
 
+class UpdateUntilBaseUnitEnum(Enum):
+  DAY = 'Day'
+  HOUR = 'Hour'
+  SAMPLE = 'Sample'
+
+
 class ImputationInput(TypedDict):
   type: ImputationTypeEnum
   maxGapLength: int
@@ -30,34 +51,47 @@ class TimeScaleInput(TypedDict):
   value: int
 
 
+class Aggregation(Enum):
+  MEAN = 'Mean'
+  SUM = 'Sum'
+  MINIMUM = 'Minumum'
+  MAXIMUM = 'Maximum'
+
+
 class UpdateTimeInput(TypedDict):
-  type: str
+  type: BasicBaseUnitEnum
   value: str
 
 
 class UpdateUntilInput(TypedDict):
-  baseUnit: str
+  baseUnit: UpdateUntilBaseUnitEnum
   offset: int
 
 
 class UpdatesInput(TypedDict):
-  column: str
+  column: Union[str, int]
   updateTime: List[UpdateTimeInput]
   updateUntil: UpdateUntilInput
 
 
 class Data(TypedDict):
-  versionId: str
-  rows: List[Range]
-  columns: List[str]
-  KPIColumn: str
-  holidayColumn: str
+  version: Id
+  rows: Union[RelativeRange, List[Range]]
+  columns: List[Union[str, int]]
+  KPIColumn: Union[str, int]
+  holidayColumn: Union[str, int]
   imputation: ImputationInput
   timeScale: TimeScaleInput
-  aggregation: str
+  aggregation: Aggregation
   updates: List[UpdatesInput]
 
 
+class DetectData(TypedDict):
+  version: Id
+  rows: Union[RelativeRange, List[Range]]
+  imputation: ImputationInput
+
+
 class DomainSpecificsInput(TypedDict):
   perspective: str
   sensitivity: float
@@ -91,29 +125,29 @@ class Configuration(TypedDict):
   anomalousBehaviorModel: AnomalousBehaviorModelInput
 
 
-class AnomalyDetectionJobConfiguration(TypedDict):
+class AnomalyDetectionJobConfiguration(TypedDict, total=False):
   name: str
-  useCaseId: str
+  useCase: Id
   data: Data
   configuration: Configuration
 
 
+class AnomalyDetectionDetectConfiguration(TypedDict, total=False):
+  name: str
+  data: DetectData
+
+
 class BuildModelResponse(TypedDict):
   id: str
   expectedResultsTableSize: float
 
 
-class CreateAnomalyDetectionConfiguration(TypedDict):
+class BuildAnomalyDetectionModelConfiguration(TypedDict):
   name: str
   configuration: Configuration
   data: Data
 
 
-class ExecuteResponse(TypedDict):
-  message: str
-  code: str
-
-
 class AccuracyMetrics(TypedDict):
   mape: float
   rmse: float
@@ -133,21 +167,35 @@ class ErrorMeasures(TypedDict):
   samplesAhead: List[SampleMeasures]
 
 
+class AnomalyDetectionType(Enum):
+  BUILD_MODEL = 'build-model'
+  REBUILD_MODEL = 'rebuild-model'
+  DETECT = 'detect'
+  RCA = 'rca'
+
+
+class JobLoad(Enum):
+  LIGHT = 'Light'
+  HEAVY = 'Heavy'
+
+
 class AnomalyDetection(TypedDict):
   id: str
   name: str
-  type: str
-  status: str
-  parentId: str
+  type: AnomalyDetectionType
+  status: Status
+  parentJob: Id
   sequenceId: str
-  useCaseId: str
-  experimentId: str
-  dataVersionId: str
+  useCase: Id
+  experiment: Id
+  dataset: Version
   createdAt: str
   completedAt: str
   executedAt: str
   workerVersion: float
   registrationBody: AnomalyDetectionJobConfiguration
+  jobLoad: JobLoad
+  calculationTime: str
 
 
 class Part(TypedDict):
@@ -159,7 +207,7 @@ class Part(TypedDict):
   knot: float
   subtype: int
   period: int
-  cosOrders: List[float]
+  cosOrder: List[float]
   sinOrder: List[float]
   unit: str
   day: int
@@ -187,6 +235,8 @@ class AnomalyDetectionJobNormalBehaviorModelModel(TypedDict):
 class VariableProperties(TypedDict):
   name: str
   importance: float
+  dataFrom: int
+  dataTo: int
 
 
 class AnomalyDetectionJobNormalBehaviorModel(TypedDict):
@@ -206,7 +256,7 @@ class AnomalyDetectionJobModelResult(TypedDict):
 
 
 class ExecuteAnomalyDetectionJobResponse(NamedTuple):
-  metaData: Optional[AnomalyDetection]
+  metadata: Optional[AnomalyDetection]
   model_result: Optional[AnomalyDetectionJobModelResult]
   table_result: Optional[DataFrame]
   logs: List[Logs]
@@ -220,8 +270,8 @@ class AnomalyDetectionResultsResponse(NamedTuple):
 
 
 class AnomalyDetectionListPayload(TypedDict):
-  experimentId: str
-  useCaseId: str
+  experiment: Id
+  useCase: Id
   type: str
   parentId: str
   sort: str
