@@ -59,7 +59,7 @@ class Variables(TypedDict):
 class DatasetListVersion(TypedDict):
   id: str
   createdAt: str
-  status: str
+  status: Status
 
 
 class DatasetVersion(TypedDict):
@@ -71,7 +71,7 @@ class DatasetVersion(TypedDict):
   lastTimestamp: str
   variables: List[Variables]
   createdAt: str
-  status: str
+  status: Status
 
 
 class CSVSeparator(Enum):
@@ -80,6 +80,10 @@ class CSVSeparator(Enum):
   COMMA = ','
 
 
+class Workspace(TypedDict):
+  id: str
+
+
 class UploadCSVConfiguration(TypedDict, total=False):
   timestampFormat: str
   timestampColumn: Union[str, int]
@@ -87,7 +91,7 @@ class UploadCSVConfiguration(TypedDict, total=False):
   name: str
   description: str
   samplingPeriod: RelativeRange
-  workspaceId: str
+  workspace: Workspace
 
 
 class UploadCSVVersion(TypedDict):
