@@ -2,7 +2,7 @@ from pandas.core.frame import DataFrame
 from enum import Enum
 from typing import Any, List, Union, NamedTuple, Optional
 from typing_extensions import TypedDict
-from tim.types import Logs
+from tim.types import Logs, Status, Id, Version
 
 Range = TypedDict('Range', {'from': str, 'to': str})
 
@@ -113,12 +113,12 @@ class Data(TypedDict, total=False):
 
 class ForecastJobConfiguration(TypedDict, total=False):
   name: str
-  useCaseId: str
+  useCase: Id
   configuration: Configuration
   data: Data
 
 
-class CreateForecastConfiguration(TypedDict, total=False):
+class BuildForecastingModelConfiguration(TypedDict, total=False):
   name: str
   configuration: Configuration
   data: Data
@@ -147,27 +147,29 @@ class ForecastJobType(Enum):
   RCA = 'rca'
 
 
+class JobLoad(Enum):
+  LIGHT = 'Light'
+  HEAVY = 'Heavy'
+
+
 class ForecastMetadata(TypedDict):
   id: str
   name: str
   type: ForecastJobType
-  status: str
-  parentId: str
+  status: Status
+  parentJob: Id
   sequenceId: str
-  useCaseId: str
-  experimentId: str
-  dataVersionId: str
+  useCase: Id
+  experiment: Id
+  dataset: Version
   createdAt: str
   executedAt: str
   completedAt: str
   workerVersion: float
   errorMeasures: ErrorMeasures
   registrationBody: ForecastJobConfiguration
-
-
-class ExecuteResponse(TypedDict):
-  message: str
-  code: str
+  jobLoad: JobLoad
+  calculationTime: str
 
 
 class Part(TypedDict):
@@ -211,7 +213,6 @@ class VariableProperties(TypedDict):
 
 class ModelZoo(TypedDict):
   samplingPeriod: str
-  originalSamplingPeriod: str
   averageTrainingLength: int
   models: List[ModelZooModel]
   difficulty: int
@@ -247,7 +248,7 @@ class ForecastAccuracies(TypedDict):
 
 
 class ExecuteForecastJobResponse(NamedTuple):
-  metaData: Optional[ForecastMetadata]
+  metadata: Optional[ForecastMetadata]
   model_result: Optional[ForecastModelResult]
   table_result: Optional[DataFrame]
   accuracies: Optional[ForecastAccuracies]
